==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_DataViewSortedListModel.h <==
//----------------------------------------------------------------------------
// wxDataViewSortedListModel
// extracted from dataviewmodel.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_DATAVIEWSORTEDLISTMODEL_H__
#define __CLASS_WX_DATAVIEWSORTEDLISTMODEL_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxDataViewSortedListModel
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_DataViewSortedListModel);

//----------------------------------------------------------------------------
// Object declaration for wxDataViewSortedListModel
//----------------------------------------------------------------------------
class Object_wx_DataViewSortedListModel : public Object_wx_DataViewListModel {
public:
	Gura_DeclareObjectAccessor(wx_DataViewSortedListModel)
public:
	inline Object_wx_DataViewSortedListModel(wxDataViewSortedListModel *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_DataViewListModel(Gura_UserClass(wx_DataViewSortedListModel), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_DataViewSortedListModel(Class *pClass, wxDataViewSortedListModel *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_DataViewListModel(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_DataViewSortedListModel();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxDataViewSortedListModel *GetEntity() {
		return dynamic_cast<wxDataViewSortedListModel *>(_pEntity);
	}
	inline wxDataViewSortedListModel *ReleaseEntity() {
		wxDataViewSortedListModel *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxDataViewSortedListModel");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_DataViewSortedListModel.h <==
//----------------------------------------------------------------------------
// wxDataViewSortedListModel
// extracted from dataviewmodel.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_DATAVIEWSORTEDLISTMODEL_H__
#define __CLASS_WX_DATAVIEWSORTEDLISTMODEL_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxDataViewSortedListModel
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_DataViewSortedListModel);

//----------------------------------------------------------------------------
// Object declaration for wxDataViewSortedListModel
//----------------------------------------------------------------------------
class Object_wx_DataViewSortedListModel : public Object_wx_DataViewListModel {
public:
	Gura_DeclareObjectAccessor(wx_DataViewSortedListModel)
public:
	inline Object_wx_DataViewSortedListModel(wxDataViewSortedListModel *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_DataViewListModel(Gura_UserClass(wx_DataViewSortedListModel), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_DataViewSortedListModel(Class *pClass, wxDataViewSortedListModel *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_DataViewListModel(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_DataViewSortedListModel();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxDataViewSortedListModel *GetEntity() {
		return dynamic_cast<wxDataViewSortedListModel *>(_pEntity);
	}
	inline wxDataViewSortedListModel *ReleaseEntity() {
		wxDataViewSortedListModel *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxDataViewSortedListModel");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
